/* ver.B.b13(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"vtester",
	"(C) 2000-2005 Hirohisa Mori",
	"ver.B.b13(BLAZE)",
	2006,10,17,
	0,
	"VObject tester ",
};

